@@ -99,7 +99,8 @@ darkyellow = brown
 fuscia = fuchsia
 
 # Other nice-to-have characters:
-class _Characters:
+class UnicodeSequence:
+    """ Represent a sequence containing a color followed by a Unicode symbol """
     def __init__(self, color, as_unicode, as_ascii):
         if os.name == "nt":
             self.as_string = as_ascii
@@ -111,9 +112,17 @@ class _Characters:
         return (reset, self.color, self.as_string, reset)
 
 
-ellipsis = _Characters(reset, "…", "...")
-check    = _Characters(green, "✓", "ok")
-cross    = _Characters(red,   "❌","ko")
+ellipsis = UnicodeSequence(reset, "…", "...")
+check    = UnicodeSequence(green, "✓", "ok")
+cross    = UnicodeSequence(red,   "❌","ko")
+
+
+class Symbol(UnicodeSequence):
+    def __init__(self, as_unicode, as_ascii):
+        super().__init__(reset, as_unicode, as_ascii)
+
+    def tuple(self):
+        return (self.as_string,)
 
 
 def using_colorama():
@@ -161,10 +170,11 @@ def process_tokens(tokens, *, end="\n", sep=" "):
     only the 'normal' characters
 
     """
-    # Flatten the list of tokens in case some of them are of class _Characters
+    # Flatten the list of tokens in case some of them are of
+    # class UnicodeSequence:
     flat_tokens = list()
     for token in tokens:
-        if isinstance(token, _Characters):
+        if isinstance(token, UnicodeSequence):
             flat_tokens.extend(token.tuple())
         else:
             flat_tokens.append(token)
@@ -230,7 +240,7 @@ def message(*tokens, **kwargs):
 
 
 def fatal(*tokens, **kwargs):
-    """ Print an error message and calls ``sys.exit`` """
+    """ Print an error message and call ``sys.exit`` """
     error(*tokens, **kwargs)
     sys.exit(1)
 
@@ -409,9 +419,7 @@ def read_input():
 
 
 def ask_string(question, default=None):
-    """Ask the user to enter something.
-
-    Returns what the user entered
+    """Ask the user to enter a string.
     """
     if default:
         question += " (%s)" % default
@@ -430,7 +438,7 @@ def ask_choice(input_text, choices,  *, func_desc=None):
 
     :return: the selected choice
 
-    ``func_desc`` will be called on list item for displaying
+    ``func_desc`` will be called on every list item for displaying
     and sorting the list. If not given, will default to
     the identity function.
 
@@ -544,6 +552,9 @@ def did_you_mean(message, user_input, choices):
 
 
 if __name__ == "__main__":
+    info("OK", check)
+    up = Symbol("👍", "+1")
+    info("I like it", blue, up)
     info_section(bold, "python-cli demo")
     # Monkey-patch message() so that we sleep after
     # each call
